pub enum ApprovalState {
Draft,
TrainerApproved {
trainer_id: StaffId,
},
ManagerApproved {
manager_id: ManagerId,
},
Rejected {
gate: ReviewGate,
},
}Expand description
Approval state for progress reports before they become parent-facing summaries.
Variants
Draft
Staff can see the draft training state during training enrollment, curriculum, progress, package, trainer-capacity, or follow-up review.
TrainerApproved
Staff can see the trainer approved training state during training enrollment, curriculum, progress, package, trainer-capacity, or follow-up review.
Fields
ManagerApproved
Staff can see the manager approved training state during training enrollment, curriculum, progress, package, trainer-capacity, or follow-up review.
Fields
Rejected
Staff can see the rejected training state during training enrollment, curriculum, progress, package, trainer-capacity, or follow-up review.
Fields
gate: ReviewGateReview gate that must clear before this training decision affects assignment, package use, or parent-facing copy.