pub enum Error {
ProgressEvidenceRequired,
OutcomeEvidenceRequired,
OutcomeClaimRequired,
PackageHasNoReusableBalance,
}Expand description
Training-domain validation failures that prevent unsupported reports, outcomes, or package usage from entering workflow state.
Variants
ProgressEvidenceRequired
Staff can see the progress evidence required training state during training enrollment, curriculum, progress, package, trainer-capacity, or follow-up review.
OutcomeEvidenceRequired
Staff can see the outcome evidence required training state during training enrollment, curriculum, progress, package, trainer-capacity, or follow-up review.
OutcomeClaimRequired
Staff can see the outcome claim required training state during training enrollment, curriculum, progress, package, trainer-capacity, or follow-up review.
PackageHasNoReusableBalance
Staff can see the package has no reusable balance training state during training enrollment, curriculum, progress, package, trainer-capacity, or follow-up review.