pub enum FollowUpCadence {
None,
AfterEachSession,
AfterProgramCompletion,
ThirtyDaysAfterCompletion,
}Expand description
Follow-up cadence that determines whether a progress/homework/re-enrollment message is due.
Variants
None
No additional workflow gate is required.
AfterEachSession
After each session training operational signal for enrollment, curriculum, progress, package, or follow-up handling.
AfterProgramCompletion
After program completion training operational signal for enrollment, curriculum, progress, package, or follow-up handling.
ThirtyDaysAfterCompletion
Thirty days after completion training operational signal for enrollment, curriculum, progress, package, or follow-up handling.