pub enum Outcome {
BasicManners,
ReducedReactivity,
CanineGoodCitizenReadiness,
OwnerHandlingPlan,
}Expand description
Outcome claim vocabulary that must be backed by trainer evidence before customer-facing use.
Variants
BasicManners
Staff can see the basic manners training state during training enrollment, curriculum, progress, package, trainer-capacity, or follow-up review.
ReducedReactivity
Staff can see the reduced reactivity training state during training enrollment, curriculum, progress, package, trainer-capacity, or follow-up review.
CanineGoodCitizenReadiness
Staff can see the canine good citizen readiness training state during training enrollment, curriculum, progress, package, trainer-capacity, or follow-up review.
OwnerHandlingPlan
Staff can see the owner handling plan training state during training enrollment, curriculum, progress, package, trainer-capacity, or follow-up review.