pub enum Program {
StayAndStudy {
duration: DurationWeeks,
},
TutorSession,
GroupClass,
PuppyKindergarten,
PrivateLesson,
AkcCanineGoodCitizenPrep,
}Expand description
Training program sold or fulfilled by the resort, used for capacity, package, and outcome planning.
Variants
StayAndStudy
Duration used by staff to prepare training assignment, package, progress, or parent-summary review.
Fields
duration: DurationWeeksStay-and-study duration staff should use for package and schedule planning.
TutorSession
Staff can see the tutor session training state during training enrollment, curriculum, progress, package, trainer-capacity, or follow-up review.
GroupClass
Staff can see the group class training state during training enrollment, curriculum, progress, package, trainer-capacity, or follow-up review.
PuppyKindergarten
Staff can see the puppy kindergarten training state during training enrollment, curriculum, progress, package, trainer-capacity, or follow-up review.
PrivateLesson
Staff can see the private lesson training state during training enrollment, curriculum, progress, package, trainer-capacity, or follow-up review.
AkcCanineGoodCitizenPrep
Staff can see the AKC canine good citizen prep training state during training enrollment, curriculum, progress, package, trainer-capacity, or follow-up review.