pub enum Error {
ProgressEvidenceRequired,
OutcomeEvidenceRequired,
OutcomeClaimRequired,
PackageHasNoReusableBalance,
}Expand description
Training-domain validation failures that prevent unsupported reports, outcomes, or package usage from entering workflow state.
Variants
ProgressEvidenceRequired
Progress evidence required training operational signal for enrollment, curriculum, progress, package, or follow-up handling.
OutcomeEvidenceRequired
Outcome evidence required training operational signal for enrollment, curriculum, progress, package, or follow-up handling.
OutcomeClaimRequired
Outcome claim required training operational signal for enrollment, curriculum, progress, package, or follow-up handling.
PackageHasNoReusableBalance
Package has no reusable balance training operational signal for enrollment, curriculum, progress, package, or follow-up handling.